@@ -12,7 +12,7 @@ import sys
 import tempfile
 from datetime import datetime
 from pathlib import Path
-from typing import Optional
+from typing import List, Optional
 
 from aind_codeocean_api.codeocean import CodeOceanClient
 from botocore.exceptions import ClientError
@@ -110,6 +110,30 @@ class GenericS3UploadJob:
                     dryrun=self.configs.dry_run,
                 )
 
+    def upload_metadata_from_folder(self) -> List[str]:
+        """Uploads json files stored in the user defined metadata directory.
+        By default, the files generated by aind-metadata-service
+        (subject.json etc.) will override the ones found in this directory
+        unless the user sets the flag --metadata-dir-force."""
+        # Get a list of file names for use later
+        file_names = [
+            fn
+            for fn in os.listdir(self.configs.metadata_dir)
+            if fn.endswith(".json")
+        ]
+        # Exclude all files, then add include so that only json files are
+        # uploaded.
+        upload_to_s3(
+            directory_to_upload=self.configs.metadata_dir,
+            s3_bucket=self.configs.s3_bucket,
+            s3_prefix=self.s3_prefix,
+            dryrun=self.configs.dry_run,
+            excluded="*",
+            included="*.json",
+        )
+
+        return file_names
+
     def upload_subject_metadata(self) -> None:
         """Retrieves subject metadata from metadata service and copies it to
         s3. Logs warning if unable to retrieve metadata from service."""
@@ -269,8 +293,8 @@ class GenericS3UploadJob:
     def _parse_date(date: str) -> str:
         """Parses date string to %YYYY-%MM-%DD format"""
         stripped_date = date.strip()
-        pattern = "^\d{4}-\d{2}-\d{2}$"
-        pattern2 = "^\d{1,2}/\d{1,2}/\d{4}$"
+        pattern = r"^\d{4}-\d{2}-\d{2}$"
+        pattern2 = r"^\d{1,2}/\d{1,2}/\d{4}$"
         if re.match(pattern, stripped_date):
             parsed_date = datetime.strptime(stripped_date, "%Y-%m-%d")
             return parsed_date.strftime("%Y-%m-%d")
@@ -286,8 +310,8 @@ class GenericS3UploadJob:
     def _parse_time(time: str) -> str:
         """Parses time string to "%HH-%MM-%SS format"""
         stripped_time = time.strip()
-        pattern = "^\d{1,2}-\d{1,2}-\d{1,2}$"
-        pattern2 = "^\d{1,2}:\d{1,2}:\d{1,2}$"
+        pattern = r"^\d{1,2}-\d{1,2}-\d{1,2}$"
+        pattern2 = r"^\d{1,2}:\d{1,2}:\d{1,2}$"
         if re.match(pattern, stripped_time):
             parsed_time = datetime.strptime(stripped_time, "%H-%M-%S")
             return parsed_time.strftime("%H-%M-%S")
@@ -331,12 +355,15 @@ class GenericS3UploadJob:
         parser.add_argument("-a", "--acq-date", required=True, type=str)
         parser.add_argument("-t", "--acq-time", required=True, type=str)
         parser.add_argument("-v", "--behavior-dir", required=False, type=str)
+        parser.add_argument("-x", "--metadata-dir", required=False, type=str)
         parser.add_argument(
             "-e", "--service-endpoints", required=False, type=json.loads
         )
         parser.add_argument("-r", "--s3-region", required=False, type=str)
         parser.add_argument("--dry-run", action="store_true")
+        parser.add_argument("--metadata-dir-force", action="store_true")
         parser.set_defaults(dry_run=False)
+        parser.set_defaults(metadata_dir_force=False)
         parser.set_defaults(s3_region=self.S3_DEFAULT_REGION)
         job_args = parser.parse_args(args)
         if job_args.service_endpoints is None:
@@ -352,12 +379,13 @@ class GenericS3UploadJob:
 
         data_prefix = "/".join([self.s3_prefix, self.configs.modality])
 
+        # Optionally upload the data in the behavior directory to s3
         behavior_dir = self.configs.behavior_dir
         if behavior_dir is not None:
             self.compress_and_upload_behavior_data()
             behavior_dir = Path(behavior_dir) / "*"
 
-        # Upload non-behavior data to s3 first
+        # Upload non-behavior data to s3
         upload_to_s3(
             directory_to_upload=self.configs.data_source,
             s3_bucket=self.configs.s3_bucket,
@@ -366,11 +394,32 @@ class GenericS3UploadJob:
             excluded=behavior_dir,
         )
 
-        # Create subject.json file if metadata service url is provided
-        self.upload_subject_metadata()
+        # Optionally upload the data in the metadata directory to s3
+        metadata_dir = self.configs.metadata_dir
+        user_defined_metadata_files = None
+        if metadata_dir is not None:
+            user_defined_metadata_files = self.upload_metadata_from_folder()
 
-        # Create data description file
-        self.upload_data_description_metadata()
+        # Will create a data description file if not found in user defined
+        # metadata directory. Assumes data description built by this job
+        # is the source of truth unless metadata-dir-force is set.
+        if (
+            (user_defined_metadata_files is None)
+            or ("data_description.json" not in user_defined_metadata_files)
+            or (self.configs.metadata_dir_force is False)
+        ):
+            self.upload_data_description_metadata()
+
+        # Create subject.json file if metadata service url is provided
+        # Will not upload if subject.json in user defined metadata folder and
+        # force command present. Assumes aind-metadata-service is source of
+        # truth by default.
+        if (
+            (user_defined_metadata_files is None)
+            or ("subject.json" not in user_defined_metadata_files)
+            or (self.configs.metadata_dir_force is False)
+        ):
+            self.upload_subject_metadata()
 
         # Register to code ocean if url is provided
         self.trigger_codeocean_capsule()
@@ -387,7 +436,9 @@ class GenericS3UploadJobList:
         "modality",
         "acq-date",
         "acq-time",
-        "behavior-dir",
+        "behavior-dir",  # Optional
+        "metadata-dir",  # Optional
+        "metadata-dir-force",  # Optional
     ]
 
     def __init__(self, args: list) -> None:
@@ -403,7 +454,8 @@ class GenericS3UploadJobList:
         help_message_csv_file = (
             "Path to csv file with list of job configs. The csv file needs "
             "to have the headers: data-source, s3-bucket, subject-id, "
-            "modality, acq-date, acq-time. Optional header: behavior-dir."
+            "modality, acq-date, acq-time. Optional headers: behavior-dir, "
+            "metadata-dir."
         )
         help_message_dry_run = (
             "Tests the upload without actually uploading the files."
@@ -432,13 +484,18 @@ class GenericS3UploadJobList:
             for row in reader:
                 job_list.append(row)
         assert len(job_list) > 0
-        assert (
-            sorted(job_list[0].keys()) == sorted(self.CSV_FILE_FIELD_NAMES)
-        ) or (
-            sorted(job_list[0].keys())
-            == sorted(self.CSV_FILE_FIELD_NAMES[0:-1])
+        # We want to check that the csv header contains the proper info.
+        # Must contain relevant keys but does not need to contain the
+        # optional keys. There's probably a cleaner way to do this?
+        job_list_keys = job_list[0].keys()
+        assert len(job_list_keys) == len(set(job_list_keys))
+        assert set(self.CSV_FILE_FIELD_NAMES[0:-3]).issubset(
+            set(job_list_keys)
         )
+        assert set(job_list_keys).issubset(self.CSV_FILE_FIELD_NAMES)
         param_list = list()
+        # Loop through rows in job_list csv file. Build the shell command
+        # from items in the row. Can ignore the optional settings.
         for job_item in job_list:
             res = [
                 x
@@ -446,12 +503,22 @@ class GenericS3UploadJobList:
                     ("--" + keys[0], keys[1])
                     for keys in job_item.items()
                     if (
-                        (keys[0] != "behavior-dir")
-                        or ((keys[1] is not None) and (keys[1] != ""))
+                        (keys[0] != "metadata-dir-force")
+                        and (
+                            (keys[0] not in ["behavior-dir", "metadata-dir"])
+                            or ((keys[1] is not None) and (keys[1] != ""))
+                        )
                     )
                 ]
                 for x in t
             ]
+            # Convert metadata-dir-force to a flag if it's been set in csv file
+            if (job_item.get("metadata-dir-force") is not None) and (
+                job_item.get("metadata-dir-force")
+                in ["True", "true", "t", "T", "Yes", "yes", "y", "1"]
+            ):
+                res.append("--metadata-dir-force")
+            # Add dry-run command if set in command line.
             if self.configs.dry_run:
                 res.append("--dry-run")
             param_list.append(res)
