@@ -15,11 +15,13 @@ class TestImagingReaders(unittest.TestCase):
     imaging_dir = RESOURCES_DIR / "imaging"
     exaspim_dir = imaging_dir / "exaSPIM_125L_2022-08-05_17-25-36"
     mesospim_dir = imaging_dir / "mesoSPIM_125L_2022-08-18_17-05-00"
+    generic_dir = imaging_dir / "12345-random-sample"
 
     @parameterized.expand(
         [
             (ImagingReaders.Readers.exaspim.value, exaspim_dir),
             (ImagingReaders.Readers.mesospim.value, mesospim_dir),
+            (ImagingReaders.Readers.generic.value, generic_dir),
         ]
     )
     def test_get_raw_data_dir(self, reader, input_dir):
@@ -31,6 +33,7 @@ class TestImagingReaders(unittest.TestCase):
         [
             ImagingReaders.Readers.exaspim.value,
             ImagingReaders.Readers.mesospim.value,
+            ImagingReaders.Readers.generic.value
         ]
     )
     def test_get_raw_data_dir_fails(self, reader):
